from django import forms
from django.utils.translation import ugettext_lazy as _


class SearchForm(forms.Form):
    '''
    Form for search bar of the XListView
    '''
    search = forms.CharField(
                            label='',
                            max_length=128,
                            required=False,
                            widget=forms.TextInput(
                                    attrs={'placeholder': _('search')}))

    def __init__(self, *args, **kwargs):
        '''
        Method for initial values and functions for the SearchForm form class
        '''
        try:
            self.fields['search'].initial = kwargs.pop('search')
        except Exception:
            pass

        # get the initial form class values
        super(SearchForm, self).__init__(*args, **kwargs)



from django.db import models
from django.contrib.auth import get_user_model
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes.fields import GenericForeignKey
from django.utils.translation import ugettext_lazy as _

# Create your models here.


class ActivityManager(models.Manager):
    '''
    Activiy Manager
    '''
    use_in_migrations = True

    def create_activity(self, activity_object, activity, message, user):
        '''
        Create activity record
        '''
        return self.model.objects.create(
                            user=user,
                            activity_object=activity_object,
                            activity=activity,
                            message=message,
                            model=activity_object.__class__.__name__
        )


class XActivity(models.Model):
    '''
    Store all user activities
    '''
    # Choices
    CREATE = 'CR'
    EDIT = 'ED'
    DELETE = 'DE'
    RESET = 'RE'
    DOWNLOAD = 'DW'
    BACKUP = 'BC'
    RESTORE = 'RS'
    EXPORT = 'EX'
    IMPORT = 'IM'
    PUBLISH = 'PU'
    ACCEPT = 'AC'
    REJECT = 'RJ'
    ENABLE = 'EN'
    DISABLE = 'DI'
    ACTIVATE = 'AV'
    DEACTIVATE = 'DV'
    BLOCK = 'BL'
    APPROVE = 'AP'
    LIKE = 'LK'
    UNLIKE = 'UL'
    RECOMMEND = 'RC'
    UNRECOMMEND = 'UC'
    activity_choices = [
                        (CREATE, _('Create')),
                        (EDIT, _('Edit')),
                        (DELETE, _('Delete')),
                        (RESET, _('Reset Password')),
                        (DOWNLOAD, _('Download')),
                        (BACKUP, _('Backup')),
                        (RESTORE, _('Restore')),
                        (EXPORT, _('Export')),
                        (IMPORT, _('Import')),
                        (PUBLISH, _('Publish')),
                        (ACCEPT, _('Accept')),
                        (REJECT, _('Reject')),
                        (ENABLE, _('Enable')),
                        (DISABLE, _('Disable')),
                        (ACTIVATE, _('Activate')),
                        (DEACTIVATE, _('Deactivate')),
                        (BLOCK, _('Block')),
                        (APPROVE, _('Approve')),
                        (LIKE, _('Like')),
                        (UNLIKE, _('Unlike')),
                        (RECOMMEND, _('Recommend')),
                        (UNRECOMMEND, _('Unrecommend')),
    ]
    #####################
    user = models.ForeignKey(
                        get_user_model(),
                        related_name='x_user_activity',
                        verbose_name=_('User'),
                        on_delete=models.CASCADE,
                        blank=False,
                        null=False
    )
    activity = models.CharField(
                        verbose_name=_('Activity'),
                        max_length=2,
                        choices=activity_choices,
                        null=False,
                        blank=False
    )
    model = models.CharField(
                        verbose_name=_('Activity model'),
                        max_length=50,
                        blank=False,
                        null=False
    )
    message = models.CharField(
                        verbose_name=_('Activity message'),
                        max_length=128,
                        blank=False,
                        null=False
    )
    activity_type = models.ForeignKey(
                        ContentType,
                        on_delete=models.SET_NULL,
                        blank=True,
                        null=True
    )
    activity_id = models.PositiveIntegerField(
                        verbose_name=_('Activity object id'),
                        blank=False,
                        null=False
    )
    activity_object = GenericForeignKey('activity_type', 'activity_id')
    created_at = models.DateTimeField(
                        verbose_name=_('Created at'),
                        auto_now_add=True,
                        blank=False
    )

    objects = ActivityManager()

    def __str__(self):
        '''
        give the string representation
        '''
        return f"{self.user.id}-{self.activity_object}-{self.activity}"



from setuptools import setup

def readme():
    with open('README.md') as f:
        README = f.read()
    return README

setup(
    name="x-django-app",
    version="1.0.6",
    description="A Python package to get weather reports for any location.",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/XecusM/x-django-app",
    author="Mohamed Aboel-fotouh",
    author_email="abo.elfotouh@live.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["x_django_app"],
    include_package_data=True,
    install_requires=['django', 'langdetect'],
)
